package com.jiuqi.sql.impl;

import com.jiuqi.sql.DBException;
import com.jiuqi.sql.FieldInfo;
import com.jiuqi.sql.InputRecordBuffer;
import java.io.IOException;
import java.io.InputStream;
import java.util.Date;

/* loaded from: com_jiuqi_sql_impl.jar:com/jiuqi/sql/impl/DBaseInputRecordBuffer.class */
public class DBaseInputRecordBuffer implements InputRecordBuffer {
    private char deleteFlag;
    private byte[] buffer;
    private boolean prevNull;
    private DBaseFileTail strValueList;
    private boolean supportText;

    public DBaseInputRecordBuffer(int recordSize, boolean supportText, DBaseFileTail strValueList) {
        this.buffer = new byte[recordSize];
        this.supportText = supportText;
        this.strValueList = strValueList;
    }

    public boolean readRecord(InputStream stream) throws DBException {
        boolean result = false;
        try {
            this.deleteFlag = (char) stream.read();
            if (!this.supportText || this.deleteFlag != 26) {
                int readSize = stream.read(this.buffer);
                result = readSize == this.buffer.length;
            }
            return result;
        } catch (IOException ex) {
            DBException dbe = new DBException();
            dbe.setStackTrace(ex.getStackTrace());
            throw dbe;
        }
    }

    public boolean isDeleted() {
        return this.deleteFlag == '*';
    }

    private boolean isNull(FieldInfo info) {
        switch (info.type) {
            case 1:
                return this.buffer[info.offset] == 32;
            case 2:
            case 8:
                boolean flag = false;
                int i = 0;
                while (true) {
                    if (i < 8) {
                        if (this.buffer[info.offset + i] == 32) {
                            i++;
                        } else {
                            flag = true;
                        }
                    }
                }
                return !flag;
            case 3:
                boolean flag2 = false;
                int i2 = 0;
                while (true) {
                    if (i2 < 8) {
                        if (this.buffer[info.offset + i2] == 0) {
                            i2++;
                        } else {
                            flag2 = true;
                        }
                    }
                }
                return !flag2;
            case 4:
            case 7:
            default:
                return false;
            case 5:
                boolean flag3 = false;
                int i3 = 0;
                while (true) {
                    if (i3 < 4) {
                        if (this.buffer[info.offset + i3] == 0) {
                            i3++;
                        } else {
                            flag3 = true;
                        }
                    }
                }
                return !flag3;
            case 6:
                boolean flag4 = false;
                int empty = 0;
                int size = info.size;
                if (this.supportText) {
                    empty = -1;
                    size = 4;
                }
                int i4 = 0;
                while (true) {
                    if (i4 < size) {
                        if (this.buffer[info.offset + i4] == empty) {
                            i4++;
                        } else {
                            flag4 = true;
                        }
                    }
                }
                return !flag4;
        }
    }

    public boolean readBoolean(FieldInfo info) throws DBException {
        this.prevNull = isNull(info);
        if (this.prevNull) {
            return false;
        }
        return RW.readBoolean(this.buffer, info.offset);
    }

    public double readDouble(FieldInfo info) throws DBException {
        this.prevNull = isNull(info);
        if (this.prevNull) {
            return 0.0d;
        }
        return RW.readDouble(this.buffer, info.offset);
    }

    public int readInt(FieldInfo info) throws DBException {
        this.prevNull = isNull(info);
        if (this.prevNull) {
            return 0;
        }
        return RW.readInt(this.buffer, info.offset);
    }

    public String readString(FieldInfo info) throws DBException {
        this.prevNull = isNull(info);
        if (this.prevNull) {
            return null;
        }
        if (this.supportText) {
            int index = RW.readInt(this.buffer, info.offset);
            return this.strValueList.get(index);
        }
        return RW.readString(this.buffer, info.offset, info.size);
    }

    public long readLong(FieldInfo info) throws DBException {
        this.prevNull = isNull(info);
        if (this.prevNull) {
            return 0L;
        }
        return RW.readLong(this.buffer, info.offset);
    }

    public Date readDate(FieldInfo info) throws DBException {
        this.prevNull = isNull(info);
        if (this.prevNull) {
            return null;
        }
        return RW.readDateTime(this.buffer, info.offset);
    }

    public boolean wasNull() throws DBException {
        return this.prevNull;
    }
}
